@@ -10,11 +10,6 @@ from fab_deploy.apache import apache_install
 from fab_deploy.nginx import nginx_install
 from fab_deploy.mysql import mysql_install
 
-def activate_snapshot(box, name):
-    box.stop()
-    box.snapshot('restore', name)
-    box.start()
-
 def deep_prepare(name):
     """ Deep VM preparation for test speedups.
     Should only be run if all related tests are passed.
@@ -28,21 +23,21 @@ def deep_prepare(name):
     env.hosts = ['foo@127.0.0.1:2222']
     env.password = '123'
     env.disable_known_hosts = True
-    env.conf = {'DB_PASSWORD': '123'}
+    env.conf = {'DB_PASSWORD': '123', 'DB_USER': 'root'}
     env.key_filename = private_key_path()
     update_env()
 
     box = VirtualBox(name)
 
     if not box.snapshot_exists('fabtest-prepared-server'):
-        activate_snapshot(box, 'fabtest-initial')
+        box.snapshot_restore('fabtest-initial')
         setup_sudo()
         setup_ssh()
         fab(prepare_server)
         fab(apache_install)
         fab(nginx_install)
         fab(mysql_install)
-        box.snapshot('take', 'fabtest-prepared-server')
+        box.snapshot_take('fabtest-prepared-server')
 
     box.stop()
 
