@@ -10,9 +10,9 @@ LAYOUT_OPTIONS = dict(
     CONFIG_TEMPLATES_PATHS = ['hosting/staging', 'hosting'],
 )
 
+@define_host('foo2@127.0.0.1:2222', LAYOUT_OPTIONS)
 def foo_site():
-    env.hosts = ['foo2@127.0.0.1:2222']
-    env.conf = dict(
+    return dict(
         VCS = 'git',
         SERVER_NAME = 'foo.example.com',
 
@@ -21,6 +21,4 @@ def foo_site():
         DB_ROOT_PASSWORD = '123',
         DB_USER = 'foouser',
         DB_PASSWORD = 'foo123',
-    )
-    env.conf.update(LAYOUT_OPTIONS)
-    update_env()
+    )
\ No newline at end of file
