@@ -9,16 +9,16 @@ class CrontabTest(FabDeployTest):
     snapshot = 'fabtest-prepared-server'
 
     def current(self):
-        return fab(_get_current)[0]
+        return fab(_get_current)
 
     def add(self, content, marker):
-        return fab(crontab_add, content, marker)[0]
+        return fab(crontab_add, content, marker)
 
     def remove(self, marker):
-        return fab(crontab_remove, marker)[0]
+        return fab(crontab_remove, marker)
 
     def update(self, content, marker):
-        return fab(crontab_update, content, marker)[0]
+        return fab(crontab_update, content, marker)
 
     def test_crontab(self):
         line1 = '@reboot echo 123'
