@@ -42,7 +42,7 @@ class SshTest(FabDeployTest):
     def test_add_ssh_key(self):
         fab(setup_root_ssh)
         env.password = None # should use ssh key
-        self.assertEqual(fab(whoami)[0], 'root')
+        self.assertEqual(fab(whoami), 'root')
 
 
 class PrepareServerTest(FabDeployTest):
