@@ -12,7 +12,7 @@ def whoami():
 
 class BasicTest(FabDeployTest):
     def test_run_as(self):
-        user = fab(whoami)[0]
+        user = fab(whoami)
         self.assertEqual(user, 'root')
 
     def test_create_sudo_linux_account(self):
@@ -23,7 +23,7 @@ class BasicTest(FabDeployTest):
         def whoami():
             return run('whoami')
 
-        user = fab(whoami)[0]
+        user = fab(whoami)
         self.assertEqual(user, 'testsudo')
 
         @run_as('testsudo')
