@@ -17,7 +17,7 @@ def get_package_state(name):
         regexp = "^%s$" % name
         output = run('aptitude -q -F "%%c" search %s' % regexp)
         return output.splitlines()[-1]
-    return fab(command)[0]
+    return fab(command)
 
 def setup_ssh():
     fab(create_linux_account, public_key_path())
